@@ -28,10 +28,6 @@ from .servicemanager import (
     CreateServiceRequest,
     CreateServiceRolloutRequest,
     DeleteServiceRequest,
-    DisableServiceRequest,
-    DisableServiceResponse,
-    EnableServiceRequest,
-    EnableServiceResponse,
     GenerateConfigReportRequest,
     GenerateConfigReportResponse,
     GetServiceConfigRequest,
@@ -62,10 +58,6 @@ __all__ = (
     "CreateServiceRequest",
     "CreateServiceRolloutRequest",
     "DeleteServiceRequest",
-    "DisableServiceRequest",
-    "DisableServiceResponse",
-    "EnableServiceRequest",
-    "EnableServiceResponse",
     "GenerateConfigReportRequest",
     "GenerateConfigReportResponse",
     "GetServiceConfigRequest",
